@@ -4,6 +4,7 @@ Parser for DBF fields.
 import sys
 import datetime
 import struct
+from decimal import Decimal
 from .memo import BinaryMemo
 
 PY2 = sys.version_info[0] == 2
@@ -200,6 +201,17 @@ class FieldParser:
                 return None
         else:
             return None
+            
+    def parseY(self, field, data):
+        """Parse currency field (Y) and return decimal.Decimal.
+
+        The field is encoded as a 8-byte little endian integer
+        with 4 digits of precision."""
+        value = struct.unpack('<q', data)[0]
+
+        # Currency fields are stored with 4 points of precision
+        return Decimal(value) / 10000
+
 
     def parseB(self, field, data):
         """Binary memo field or double precision floating point number
